@@ -1,12 +1,13 @@
 package Statocles::Store;
 {
-  $Statocles::Store::VERSION = '0.001';
+  $Statocles::Store::VERSION = '0.002';
 }
 # ABSTRACT: A repository for Documents and Pages
 
 use Statocles::Class;
 use Statocles::Document;
 use File::Find qw( find );
+use File::Spec::Functions qw( splitdir );
 use File::Path qw( make_path );
 use File::Slurp qw( write_file );
 use YAML;
@@ -37,6 +38,7 @@ sub read_documents {
                 my @yaml_docs = YAML::LoadFile( $_ );
                 my $rel_path = $File::Find::name;
                 $rel_path =~ s/$root_path//;
+                my $doc_path = join "/", splitdir( $rel_path );
                 push @docs, map { Statocles::Document->new( path => $rel_path, %$_ ) } @yaml_docs;
             }
         },
@@ -67,7 +69,7 @@ Statocles::Store - A repository for Documents and Pages
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
